pub struct DistributedDataParallel<M: Module> { /* private fields */ }Expand description
Distributed Data Parallel wrapper for models
Implementations
Sourceimpl<M: Module> DistributedDataParallel<M>
impl<M: Module> DistributedDataParallel<M>
Sourcepub fn new(
module: M,
process_group: Arc<ProcessGroup>,
device_ids: Vec<usize>,
output_device: Option<usize>,
broadcast_buffers: bool,
bucket_cap_mb: f32,
) -> TorshResult<Self>
pub fn new( module: M, process_group: Arc<ProcessGroup>, device_ids: Vec<usize>, output_device: Option<usize>, broadcast_buffers: bool, bucket_cap_mb: f32, ) -> TorshResult<Self>
Create a new DDP wrapper
Sourcepub fn new_with_bucket_config(
module: M,
process_group: Arc<ProcessGroup>,
device_ids: Vec<usize>,
output_device: Option<usize>,
broadcast_buffers: bool,
bucket_config: BucketConfig,
) -> TorshResult<Self>
pub fn new_with_bucket_config( module: M, process_group: Arc<ProcessGroup>, device_ids: Vec<usize>, output_device: Option<usize>, broadcast_buffers: bool, bucket_config: BucketConfig, ) -> TorshResult<Self>
Create a new DDP wrapper with custom bucket configuration
Sourcepub fn new_with_configs(
module: M,
process_group: Arc<ProcessGroup>,
device_ids: Vec<usize>,
output_device: Option<usize>,
broadcast_buffers: bool,
bucket_config: BucketConfig,
overlap_config: OverlapConfig,
) -> TorshResult<Self>
pub fn new_with_configs( module: M, process_group: Arc<ProcessGroup>, device_ids: Vec<usize>, output_device: Option<usize>, broadcast_buffers: bool, bucket_config: BucketConfig, overlap_config: OverlapConfig, ) -> TorshResult<Self>
Create a new DDP wrapper with custom configurations
Sourcepub async fn sync_gradients(&mut self) -> TorshResult<()>
pub async fn sync_gradients(&mut self) -> TorshResult<()>
Synchronize gradients across all processes
Sourcepub fn register_gradient_hooks(&self) -> TorshResult<()>
pub fn register_gradient_hooks(&self) -> TorshResult<()>
Register gradient synchronization hooks This should be called during the backward pass to automatically sync gradients
Sourcepub fn register_gradient_async(
&self,
param_name: &str,
gradient: Tensor,
) -> TorshResult<()>
pub fn register_gradient_async( &self, param_name: &str, gradient: Tensor, ) -> TorshResult<()>
Register a gradient for asynchronous synchronization (overlap mode) This should be called when a gradient becomes available during backward pass
Sourcepub fn check_unused_parameters(&self) -> TorshResult<Vec<String>>
pub fn check_unused_parameters(&self) -> TorshResult<Vec<String>>
Check for unused parameters and issue warnings
Sourcepub fn start_iteration(&self) -> TorshResult<()>
pub fn start_iteration(&self) -> TorshResult<()>
Start a new iteration (reset unused parameter tracking)
Sourcepub fn get_overlap_stats(&self) -> HashMap<String, Value>
pub fn get_overlap_stats(&self) -> HashMap<String, Value>
Get overlap computation statistics
Sourcepub fn has_gradients(&self) -> bool
pub fn has_gradients(&self) -> bool
Check if any parameters have gradients
Sourcepub fn zero_grad(&mut self) -> TorshResult<()>
pub fn zero_grad(&mut self) -> TorshResult<()>
Zero all gradients
Sourcepub fn get_sync_stats(&self) -> GradientSyncStats
pub fn get_sync_stats(&self) -> GradientSyncStats
Get gradient synchronization statistics
Sourcepub fn set_bucketing_enabled(&mut self, enabled: bool) -> TorshResult<()>
pub fn set_bucketing_enabled(&mut self, enabled: bool) -> TorshResult<()>
Enable/disable gradient bucketing at runtime
Sourcepub fn get_bucket_info(&self) -> Vec<BucketInfo>
pub fn get_bucket_info(&self) -> Vec<BucketInfo>
Get bucket information for debugging
Sourcepub async fn check_gradient_consistency(&self) -> TorshResult<bool>
pub async fn check_gradient_consistency(&self) -> TorshResult<bool>
Perform a gradient consistency check across all processes This is useful for debugging distributed training issues